import contextvars
from typing import Optional

# Thread-safe and async-safe context variable for the repository path
REPO_CWD: contextvars.ContextVar[Optional[str]] = contextvars.ContextVar("REPO_CWD", default=None)
